@@ -9,7 +9,10 @@ IPC::Locker::Server - Distributed lock handler server
 
   use IPC::Locker::Server;
 
-  IPC::Locker::Server->start_server(port=>1234,);
+  IPC::Locker::Server->new(port=>1234)->start_server;
+
+  # Or more typically via the command line
+  lockerd
 
 =head1 DESCRIPTION
 
@@ -17,6 +20,10 @@ L<IPC::Locker::Server> provides the server for the IPC::Locker package.
 
 =over 4
 
+=item new ([parameter=>value ...]);
+
+Creates a server object.
+
 =item start_server ([parameter=>value ...]);
 
 Starts the server.  Does not return.
@@ -80,7 +87,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.486';
+$VERSION = '1.487';
 $Hostname = IPC::Locker::hostfqdn();
 
 ######################################################################
