@@ -20,7 +20,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.486';
+$VERSION = '1.487';
 
 $Hostname = IPC::Locker::hostfqdn();
 
@@ -101,7 +101,10 @@ IPC::PidStat::PidServer - Process ID existence server
 
   use IPC::PidStat::PidServer;
 
-  IPC::PidStat::PidServer->start_server(port=>1234,);
+  IPC::PidStat::PidServer->new(port=>1234)->start_server;
+
+  # Or more typically via the command line
+  pidstatd
 
 =head1 DESCRIPTION
 
@@ -113,6 +116,10 @@ for PIDs that no longer exists.
 
 =over 4
 
+=item new ([parameter=>value ...]);
+
+Creates a server object.
+
 =item start_server ([parameter=>value ...]);
 
 Starts the server.  Does not return.
